@@ -1,10 +1,17 @@
+# -*- coding: utf-8 -*-
+""":synopsis: Exception classes.
+
+.. moduleauthor:: Sho Nakatani <lay.sakura@gmail.com>
+"""
+
+
 class BaseError(Exception):
     """Base class for exceptions in this module."""
     pass
 
 
 class UnsupportedTypeError(BaseError):
-    """An exception raised when unsupported type is used"""
+    """An exception raised when unsupported type is used."""
     def __init__(self, msg):
         self.msg = msg
 
@@ -13,6 +20,7 @@ class UnsupportedTypeError(BaseError):
 
 
 class ColumnDefError(BaseError):
+    """An exception raised when invalid column definition is used."""
     def __init__(self, msg):
         self.msg = msg
 
@@ -20,15 +28,6 @@ class ColumnDefError(BaseError):
         return self.msg
 
 
-class RecordTypeError(BaseError):
-    """An exception raised when a record does not match with RecordDef."""
-    def __init__(self, msg):
-        self.msg = msg
-
-    def __str__(self):  # pragma: no cover
-        return self.msg
-
-
 class RecordDefError(BaseError):
     """An exception raised when input to RecordDef is invalid data structure."""
     def __init__(self, msg):
@@ -36,3 +35,12 @@ class RecordDefError(BaseError):
 
     def __str__(self):  # pragma: no cover
         return self.msg
+
+
+class RecordTypeError(BaseError):
+    """An exception raised when a record does not match with RecordDef."""
+    def __init__(self, msg):
+        self.msg = msg
+
+    def __str__(self):  # pragma: no cover
+        return self.msg
