@@ -1,23 +1,29 @@
-'''type.py
-'''
 # -*- coding: utf-8 -*-
+""":synopsis: Provides shellstreaming types.
+
+.. moduleauthor:: Sho Nakatani <lay.sakura@gmail.com>
+"""
 import types
-from error import UnsupportedTypeError
+from shellstreaming.error import UnsupportedTypeError
 
 
 class Type:
     """Types of columns."""
+
     _typemap = {
         # builtin type   : shellstreaming type
         types.IntType    : 'INT',
         types.StringType : 'STRING',
     }
+    type_list = _typemap.values()
+    """List of shellstreaming types."""
 
     # APIs
     def __init__(self, ss_type_str):
-        """
-        @param ss_type_str  string representing shellstreaming type.
-        @raises  UnsupportedTypeError
+        """Creates a Type object.
+
+        :param ss_type_str: string representing shellstreaming type (one of `Type.type_list <#shellstreaming.type.Type.type_list>`_)
+        :raises:            `UnsupportedTypeError <#shellstreaming.error.UnsupportedTypeError>`_
         """
         if ss_type_str not in Type._typemap.values():
             raise UnsupportedTypeError("Type %s is not supported as shellstreaming type" %
@@ -35,13 +41,14 @@ class Type:
 
     @staticmethod
     def equivalent_ss_type(val):
-        """Returns Type instance representing shellstreaming type.
-        @param val  value to check shellstreaming equivalent type.
-        @raises  UnsupportedTypeError
+        """Returns `val`'s shellstreaming compatible type.
+
+        :param val:  value to check shellstreaming equivalent type
+        :raises:     `UnsupportedTypeError <#shellstreaming.error.UnsupportedTypeError>`_
         """
         builtin_type = type(val)
         if builtin_type not in Type._typemap:
             raise UnsupportedTypeError("builtin type %s is not convirtible to shellstreaming type" %
                                        (builtin_type))
-        ss_type_str  = Type._typemap[builtin_type]
+        ss_type_str = Type._typemap[builtin_type]
         return Type(ss_type_str)
